@@ -13,23 +13,38 @@
 # license you chose for the specific language governing permissions and
 # limitations under that license.
 
-from logging import StreamHandler, getLogger, INFO, Formatter
+from __future__ import annotations
+
+from logging import StreamHandler, getLogger, INFO, Formatter, Handler, LogRecord
 import sys
+from typing import IO, TYPE_CHECKING
 
 from fixtures import Fixture
 from fixtures._fixtures.streams import StringStream
 
+# Type alias for proper typing during type checking
+if TYPE_CHECKING:
+    StreamHandlerStr = StreamHandler[IO[str]]
+else:
+    StreamHandlerStr = StreamHandler
+
 __all__ = [
-    'FakeLogger',
-    'LoggerFixture',
-    'LogHandler',
-    ]
+    "FakeLogger",
+    "LoggerFixture",
+    "LogHandler",
+]
 
 
 class LogHandler(Fixture):
     """Replace a logger's handlers."""
 
-    def __init__(self, handler, name="", level=None, nuke_handlers=True):
+    def __init__(
+        self,
+        handler: Handler,
+        name: str = "",
+        level: int | None = None,
+        nuke_handlers: bool = True,
+    ) -> None:
         """Create a LogHandler fixture.
 
         :param handler: The handler to replace other handlers with.
@@ -39,13 +54,13 @@ class LogHandler(Fixture):
         :param nuke_handlers: If True remove all existing handles (prevents
             existing messages going to e.g. stdout). Defaults to True.
         """
-        super(LogHandler, self).__init__()
+        super().__init__()
         self.handler = handler
         self._name = name
         self._level = level
         self._nuke_handlers = nuke_handlers
 
-    def _setUp(self):
+    def _setUp(self) -> None:
         logger = getLogger(self._name)
         if self._level:
             self.addCleanup(logger.setLevel, logger.level)
@@ -60,18 +75,27 @@ class LogHandler(Fixture):
             self.addCleanup(logger.removeHandler, self.handler)
 
 
-class StreamHandlerRaiseException(StreamHandler):
+class StreamHandlerRaiseException(StreamHandlerStr):
     """Handler class that will raise an exception on formatting errors."""
-    def handleError(self, record):
+
+    def handleError(self, record: LogRecord) -> None:
         _, value, tb = sys.exc_info()
-        raise value.with_traceback(tb)
+        if value is not None:
+            raise value.with_traceback(tb)
 
 
 class FakeLogger(Fixture):
     """Replace a logger and capture its output."""
 
-    def __init__(self, name="", level=INFO, format=None,
-                 datefmt=None, nuke_handlers=True, formatter=None):
+    def __init__(
+        self,
+        name: str = "",
+        level: int | None = INFO,
+        format: str | None = None,
+        datefmt: str | None = None,
+        nuke_handlers: bool = True,
+        formatter: type[Formatter] | None = None,
+    ) -> None:
         """Create a FakeLogger fixture.
 
         :param name: The name of the logger to replace. Defaults to "".
@@ -92,7 +116,7 @@ class FakeLogger(Fixture):
               logging.info('message')
               self.assertEqual('message', fixture.output)
         """
-        super(FakeLogger, self).__init__()
+        super().__init__()
         self._name = name
         self._level = level
         self._format = format
@@ -100,24 +124,30 @@ class FakeLogger(Fixture):
         self._nuke_handlers = nuke_handlers
         self._formatter = formatter
 
-    def _setUp(self):
-        name = "pythonlogging:'%s'" % self._name
-        output = self.useFixture(StringStream(name)).stream
-        self._output = output
+    def _setUp(self) -> None:
+        name = f"pythonlogging:'{self._name}'"
+        stream_fixture = self.useFixture(StringStream(name))
+        output = stream_fixture.stream
+        self._output: IO[str] = output
         handler = StreamHandlerRaiseException(output)
         if self._format:
-            formatter = (self._formatter or Formatter)
+            formatter = self._formatter or Formatter
             handler.setFormatter(formatter(self._format, self._datefmt))
         self.useFixture(
-            LogHandler(handler, name=self._name, level=self._level,
-                       nuke_handlers=self._nuke_handlers))
+            LogHandler(
+                handler,
+                name=self._name,
+                level=self._level,
+                nuke_handlers=self._nuke_handlers,
+            )
+        )
 
     @property
-    def output(self):
+    def output(self) -> str:
         self._output.seek(0)
         return self._output.read()
 
-    def reset_output(self):
+    def reset_output(self) -> None:
         self._output.truncate(0)
 
 
